@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: dropdownConnectPort.php 11725 2010-06-15 18:27:56Z tsmr $
+ * @version $Id: dropdownConnectPort.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -33,10 +33,11 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-$AJAX_INCLUDE=1;
+$AJAX_INCLUDE = 1;
 
 define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
+
 header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
@@ -44,11 +45,13 @@ checkRight("networking","w");
 
 // Make a select box
 if (class_exists($_POST["itemtype"]) && isset($_POST["item"])) {
-   $table=getTableForItemType($_POST["itemtype"]);
+   $table = getTableForItemType($_POST["itemtype"]);
 
    $query = "SELECT DISTINCT `glpi_networkports_networkports`.`id` AS wid,
-                    `glpi_networkports`.`id` AS did, `$table`.`name` AS cname,
-                    `glpi_networkports`.`name` AS nname, `glpi_netpoints`.`name` as npname
+                             `glpi_networkports`.`id` AS did,
+                             `$table`.`name` AS cname,
+                             `glpi_networkports`.`name` AS nname,
+                             `glpi_netpoints`.`name` AS npname
              FROM `$table`
              LEFT JOIN `glpi_networkports`
                ON (`glpi_networkports`.`items_id` = '".$_POST['item']."'
@@ -68,27 +71,31 @@ if (class_exists($_POST["itemtype"]) && isset($_POST["item"])) {
    $result = $DB->query($query);
 
    echo "<br>";
-   echo "<select name=\"".$_POST['myname']."[".$_POST["current"]."]\" size='1'>";
+   echo "<select name='".$_POST['myname']."[".$_POST["current"]."]' size='1'>";
    echo "<option value='0'>".DROPDOWN_EMPTY_VALUE."</option>";
+
    if ($DB->numrows($result)) {
       while ($data = $DB->fetch_array($result)) {
          // Device name + port name
          $output = $output_long = $data['cname'];
+
          if (!empty($data['nname'])) {
-            $output .= " - ".$data['nname'];
+            $output      .= " - ".$data['nname'];
             $output_long .= " - " . $LANG['networking'][44] . " " . $data['nname'];
          }
+
          // display netpoint (which will be copied)
          if (!empty($data['npname'])) {
-            $output .= " - ".$data['npname'];
+            $output      .= " - ".$data['npname'];
             $output_long .= " - " . $LANG['networking'][51] . " " . $data['npname'];
          }
          $ID = $data['did'];
+
          if ($_SESSION["glpiis_ids_visible"] || empty($output)) {
-            $output .= " ($ID)";
+            $output      .= " ($ID)";
             $output_long .= " ($ID)";
          }
-         $output = utf8_substr($output,0,$_SESSION["glpidropdown_chars_limit"]);
+         $output = utf8_substr($output, 0, $_SESSION["glpidropdown_chars_limit"]);
          echo "<option value='$ID' title=\"".cleanInputText($output_long)."\">".$output;
          echo "</option>";
       }
