@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: dropdownMassiveActionAuthMethods.php 11324 2010-04-20 12:00:19Z moyo $
+ * @version $Id: dropdownMassiveActionAuthMethods.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -33,23 +33,27 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-$AJAX_INCLUDE=1;	
+$AJAX_INCLUDE = 1;
 define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
+
 header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
-checkRight("user","w");
+checkRight("user", "w");
+
 if ($_POST["authtype"] > 0) {
-   $name='massiveaction';
+   $name = 'massiveaction';
+
    if (isset($_POST['name'])) {
-      $name=$_POST['name'];
+      $name = $_POST['name'];
    }
 
    switch($_POST["authtype"]) {
       case Auth::DB_GLPI :
          echo "<input type='hidden' name='auths_id' value='0'>";
          break;
+
       case Auth::LDAP :
       case Auth::EXTERNAL :
          Dropdown::show('AuthLDAP', array('name' => "auths_id"));
@@ -59,6 +63,8 @@ if ($_POST["authtype"] > 0) {
          Dropdown::show('AuthMail', array('name' => "auths_id"));
          break;
    }
-   echo "&nbsp;<input type='submit' name='$name' class='submit' value=\"".$LANG['buttons'][2]."\" >";
+
+   echo "&nbsp;<input type='submit' name='$name' class='submit' value=\"".$LANG['buttons'][2]."\">";
 }
+
 ?>
