@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: dropdownRubDocument.php 11405 2010-05-03 05:50:28Z moyo $
+ * @version $Id: dropdownRubDocument.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -34,7 +34,7 @@
 // ----------------------------------------------------------------------
 
 if (strpos($_SERVER['PHP_SELF'],"dropdownRubDocument.php")) {
-   $AJAX_INCLUDE=1;
+   $AJAX_INCLUDE = 1;
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
@@ -46,22 +46,28 @@ checkCentralAccess();
 // Make a select box
 if (isset($_POST["rubdoc"])) {
    if (!is_array($_POST['used'])) {
-      $_POST['used']=unserialize(stripslashes($_POST['used']));
+      $_POST['used'] = unserialize(stripslashes($_POST['used']));
    }
-   $used=array();
+   $used = array();
+
    // Clean used array
    if (is_array($_POST['used']) && count($_POST['used'])>0) {
-      $query="SELECT id FROM glpi_documents WHERE id IN (".implode(',',$_POST['used']).") AND documentcategories_id='".$_POST["rubdoc"]."'";
+      $query = "SELECT `id`
+                FROM `glpi_documents`
+                WHERE `id` IN (".implode(',',$_POST['used']).")
+                      AND `documentcategories_id` = '".$_POST["rubdoc"]."'";
+
       foreach ($DB->request($query) AS $data) {
-         $used[$data['id']]=$data['id'];
+         $used[$data['id']] = $data['id'];
       }
    }
-   Dropdown::show('Document',array('name'    => $_POST['myname'],
-                                    'used'     => $used,
-                                    'entity'   => $_POST['entity'],
-                                    'rand'   => $_POST['rand'],
-                                    'condition'=> "glpi_documents.documentcategories_id='".$_POST["rubdoc"]."'"
-                              ));
+
+   Dropdown::show('Document',
+                  array('name'      => $_POST['myname'],
+                        'used'      => $used,
+                        'entity'    => $_POST['entity'],
+                        'rand'      => $_POST['rand'],
+                        'condition' => "glpi_documents.documentcategories_id='".$_POST["rubdoc"]."'"));
 }
 
 ?>
