@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: dropdownRules.php 11725 2010-06-15 18:27:56Z tsmr $
+ * @version $Id: dropdownRules.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -49,29 +49,31 @@ checkLoginUser();
 
 // Make a select box with preselected values
 if (!isset($_POST["limit"])) {
-   $_POST["limit"]=$_SESSION["glpidropdown_chars_limit"];
+   $_POST["limit"] = $_SESSION["glpidropdown_chars_limit"];
 }
 
-$NBMAX=$CFG_GLPI["dropdown_max"];
-$LIMIT="LIMIT 0,$NBMAX";
+$NBMAX = $CFG_GLPI["dropdown_max"];
+$LIMIT = "LIMIT 0,$NBMAX";
 
 $sql = "SELECT `id`, `name`, `ranking`
         FROM `glpi_rules`
-        WHERE `sub_type`='".$_POST["type"]."'";
+        WHERE `sub_type` = '".$_POST["type"]."'";
 
 if ($_POST['searchText']==$CFG_GLPI["ajax_wildcard"]) {
-   $LIMIT="";
+   $LIMIT = "";
 } else {
    $sql .= " AND `name` ".makeTextSearch($_POST['searchText']);
 }
+
 if (isset($_POST['entity_restrict']) && $_POST['entity_restrict']!='') {
-   $sql.=" AND `glpi_rules`.`entities_id`='".$_POST['entity_restrict']."'";
+   $sql .= " AND `glpi_rules`.`entities_id` = '".$_POST['entity_restrict']."'";
 }
+
 $sql .= " ORDER BY `ranking` ASC " .
           $LIMIT;
 $result = $DB->query($sql);
 
-echo "<select id='dropdown_".$_POST["myname"].$_POST["rand"]."' name=\"".$_POST['myname']."\" size='1'>";
+echo "<select id='dropdown_".$_POST["myname"].$_POST["rand"]."' name='".$_POST['myname']."' size='1'>";
 
 if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"] && $DB->numrows($result)==$NBMAX) {
    echo "<option value='0'>--".$LANG['common'][11]."--</option>";
@@ -81,12 +83,12 @@ if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"] && $DB->numrows($result)==$
 
 if ($DB->numrows($result)) {
    while ($data =$DB->fetch_array($result)) {
-      $ID = $data['id'];
+      $ID   = $data['id'];
       $name = $data['name'];
       echo "<option value='$ID' title=\"".cleanInputText($name)."\">".
-             utf8_substr($name,0,$_POST["limit"])."</option>";
+            utf8_substr($name, 0, $_POST["limit"])."</option>";
    }
 }
 echo "</select>";
 
-?>
\ No newline at end of file
+?>
