@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: dropdownTrackingDeviceType.php 11725 2010-06-15 18:27:56Z tsmr $
+ * @version $Id: dropdownTrackingDeviceType.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -39,29 +39,28 @@ header("Content-Type: text/html; charset=UTF-8");
 header_nocache();
 
 checkLoginUser();
+
 // Make a select box
-
-
 if (isset($_POST["itemtype"]) && Ticket::isPossibleToAssignType($_POST["itemtype"])) {
-
-   $table=getTableForItemType($_POST["itemtype"]);
-
-   $rand=mt_rand();
+   $table = getTableForItemType($_POST["itemtype"]);
+   $rand  =mt_rand();
    echo "&nbsp;";
    ajaxDisplaySearchTextForDropdown($_POST['myname'].$rand,8);
-   $paramstrackingdt=array('searchText'=>'__VALUE__',
-                           'myname'=>$_POST["myname"],
-                           'table'=>$table,
-                           'itemtype'=>$_POST["itemtype"],
-                           'entity_restrict'=>$_POST['entity_restrict']);
 
-   ajaxUpdateItemOnInputTextEvent("search_".$_POST['myname'].$rand,"results_ID$rand",
+   $paramstrackingdt = array('searchText'      => '__VALUE__',
+                             'myname'          => $_POST["myname"],
+                             'table'           => $table,
+                             'itemtype'        => $_POST["itemtype"],
+                             'entity_restrict' => $_POST['entity_restrict']);
+
+   ajaxUpdateItemOnInputTextEvent("search_".$_POST['myname'].$rand, "results_ID$rand",
                                   $CFG_GLPI["root_doc"]."/ajax/dropdownFindNum.php",
-                                  $paramstrackingdt,false);
+                                  $paramstrackingdt, false);
 
    echo "<span id='results_ID$rand'>";
    echo "<select name='id'><option value='0'>".DROPDOWN_EMPTY_VALUE."</option></select>";
    echo "</span>\n";
+
    if (!isset($_POST["admin"]) || $_POST["admin"]==0) {
       echo "<br>".$LANG['help'][23];
    }
