@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: private_public.php 11678 2010-06-11 16:34:32Z moyo $
+ * @version $Id: private_public.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -46,6 +46,7 @@ if (!defined('GLPI_ROOT')) {
 
 if (isset($_POST['is_private'])) {
    checkLoginUser();
+
    switch ($_POST['is_private']) {
       case true :
          echo "<input type='hidden' name='is_private' value='1'>\n";
@@ -60,7 +61,7 @@ if (isset($_POST['is_private'])) {
          echo $LANG['common'][76]."&nbsp;:&nbsp;";
          Dropdown::show('Entity', array('value' => $_POST["entities_id"]));
          echo "&nbsp;+&nbsp;".$LANG['entity'][9]."&nbsp;:&nbsp;";
-         Dropdown::showYesNo('is_recursive',$_POST["is_recursive"]);
+         Dropdown::showYesNo('is_recursive', $_POST["is_recursive"]);
          echo " - ";
          echo "<a onClick='setPrivate".$_POST['rand']."()'>".$LANG['common'][79]."</a>";
          break;
