@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: ruleaction.php 13303 2010-12-14 13:15:14Z moyo $
+ * @version $Id: ruleaction.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -50,22 +50,25 @@ checkLoginUser();
 // Non define case
 if (isset($_POST["sub_type"]) && class_exists($_POST["sub_type"])) {
    if (!isset($_POST["field"])) {
-      $_POST["field"]=key(Rule::getActionsByType($_POST["sub_type"]));
+      $_POST["field"] = key(Rule::getActionsByType($_POST["sub_type"]));
    }
 
-   $randaction=RuleAction::dropdownActions($_POST["sub_type"],"action_type",$_POST["field"]);
+   $randaction = RuleAction::dropdownActions($_POST["sub_type"], "action_type", $_POST["field"]);
 
    echo "&nbsp;&nbsp;";
    echo "<span id='action_type_span$randaction'>\n";
    echo "</span>\n";
 
-   $paramsaction=array('action_type'=>'__VALUE__',
-                       'field'=>$_POST["field"],
-                       'sub_type'=>$_POST["sub_type"]);
-   ajaxUpdateItemOnSelectEvent("dropdown_action_type$randaction","action_type_span$randaction",
-                               $CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",$paramsaction,false);
-   ajaxUpdateItem("action_type_span$randaction",$CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",$paramsaction,
-                  false,"dropdown_action_type$randaction");
+   $paramsaction = array('action_type' => '__VALUE__',
+                         'field'       => $_POST["field"],
+                         'sub_type'    => $_POST["sub_type"]);
+
+   ajaxUpdateItemOnSelectEvent("dropdown_action_type$randaction", "action_type_span$randaction",
+                               $CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php", $paramsaction,
+                               false);
+
+   ajaxUpdateItem("action_type_span$randaction", $CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",
+                  $paramsaction, false, "dropdown_action_type$randaction");
 }
 
 ?>
