@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: rulecriteria.php 13303 2010-12-14 13:15:14Z moyo $
+ * @version $Id: rulecriteria.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -48,40 +48,43 @@ if (!defined('GLPI_ROOT')) {
 checkLoginUser();
 
 if (isset($_POST["sub_type"])) {
-   $type = $_POST["sub_type"];
-   $rule=new $type();
-   $criterias=$rule->getCriterias();
+   $rule      = new $_POST["sub_type"];
+   $criterias = $rule->getCriterias();
+
    if (count($criterias)) {
       // First include -> first of the predefined array
       if (!isset($_POST["criteria"])) {
-         $_POST["criteria"]=key($criterias);
+         $_POST["criteria"] = key($criterias);
       }
-      $type="";
+      $type = "";
+
       if (isset($criterias[$_POST["criteria"]]['type'])) {
-         $type=$criterias[$_POST["criteria"]]['type'];
+         $type = $criterias[$_POST["criteria"]]['type'];
       }
+
       if (isset($criterias[$_POST["criteria"]]['allow_condition'])) {
-         $allow_condition=$criterias[$_POST["criteria"]]['allow_condition'];
-      }
-      else {
+         $allow_condition = $criterias[$_POST["criteria"]]['allow_condition'];
+      } else {
          $allow_condition = array();
       }
-      $randcrit = RuleCriteria::dropdownConditions($type,"condition",'',$allow_condition);
+      $randcrit = RuleCriteria::dropdownConditions($_POST["sub_type"],
+                                                   array('criterion'        => $_POST["criteria"],
+                                                         'allow_conditions' => $allow_condition));
 
       echo "&nbsp;&nbsp;";
       echo "<span id='condition_span$randcrit'>\n";
       echo "</span>\n";
 
-      $paramscriteria=array('condition'=>'__VALUE__',
-                            'criteria'=>$_POST["criteria"],
-                            'sub_type'=>$_POST["sub_type"]);
+      $paramscriteria = array('condition' => '__VALUE__',
+                              'criteria'  => $_POST["criteria"],
+                              'sub_type'  => $_POST["sub_type"]);
 
-      ajaxUpdateItemOnSelectEvent("dropdown_condition$randcrit","condition_span$randcrit",
-                                  $CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",$paramscriteria,
-                                  false);
+      ajaxUpdateItemOnSelectEvent("dropdown_condition$randcrit", "condition_span$randcrit",
+                                  $CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",
+                                  $paramscriteria, false);
 
-      ajaxUpdateItem("condition_span$randcrit",$CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",
-                     $paramscriteria,false,"dropdown_condition$randcrit");
+      ajaxUpdateItem("condition_span$randcrit", $CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",
+                     $paramscriteria, false, "dropdown_condition$randcrit");
    }
 }
 
