@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: rulecriteriavalue.php 10769 2010-02-25 16:55:55Z walid $
+ * @version $Id: rulecriteriavalue.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -49,10 +49,9 @@ checkLoginUser();
 
 // Non define case
 if (isset($_POST["sub_type"])) {
-   $type = $_POST["sub_type"];
-   $rule = new $type();
-   $criterias=$rule->getCriterias();
-   $rule->displayCriteriaSelectPattern("pattern",$_POST["criteria"],$_POST['condition']);
+   $type      = $_POST["sub_type"];
+   $rule      = new $type();
+   $rule->displayCriteriaSelectPattern("pattern", $_POST["criteria"], $_POST['condition']);
 }
 
 ?>
