@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: transfers.php 10411 2010-02-09 07:58:26Z moyo $
+ * @version $Id: transfers.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -41,7 +41,7 @@ header_nocache();
 checkRight("transfer","r");
 
 if (isset($_POST["id"]) && $_POST["id"]>0) {
-   $transfer=new Transfer();
+   $transfer = new Transfer();
    $transfer->showForm($_POST["id"],
                        array('target' => $CFG_GLPI["root_doc"]."/front/transfer.action.php"));
 }
