@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: updateMetaSearch.php 10951 2010-03-09 11:29:12Z moyo $
+ * @version $Id: updateMetaSearch.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -45,66 +45,74 @@ if (!class_exists($_POST["itemtype"])) {
 $item = new $_POST["itemtype"];
 $item->checkGlobal('r');
 
-$first_group=true;
-$newgroup="";
-$items_in_group=0;
-$searchopt=Search::getCleanedOptions($_POST["itemtype"],'r',false);
-
+$first_group    = true;
+$newgroup       = "";
+$items_in_group = 0;
+$searchopt      = Search::getCleanedOptions($_POST["itemtype"], 'r', false);
+echo "<table width='100%'><tr><td class='right'>";
 echo "<select id='Search2".$_POST["itemtype"].$_POST["num"]."' name='field2[".$_POST["num"]."]' size='1'>";
+
 foreach ($searchopt as $key => $val) {
+
    // print groups
    if (!is_array($val)) {
       if (!empty($newgroup) && $items_in_group>0) {
          echo $newgroup;
-         $first_group=false;
+         $first_group = false;
       }
-      $items_in_group=0;
-      $newgroup="";
+      $items_in_group = 0;
+      $newgroup       = "";
       if (!$first_group) {
-         $newgroup.="</optgroup>";
+         $newgroup .= "</optgroup>";
       }
-      $newgroup.="<optgroup label='$val'>";
+      $newgroup .= "<optgroup label=\"$val\">";
+
    } else {
       // No search on plugins
       echo $key."--";
       if (!isPluginItemType($key) && !isset($val["nometa"])) {
-         $newgroup.= "<option value='$key' title=\"".cleanInputText($val["name"])."\"";
+         $newgroup .= "<option value='$key' title=\"".cleanInputText($val["name"])."\"";
          if ($key == $_POST["field"]) {
-            $newgroup.= "selected";
+            $newgroup .= "selected";
          }
-         $newgroup.= ">". utf8_substr($val["name"],0,20) ."</option>\n";
+         $newgroup .= ">". utf8_substr($val["name"], 0, 20) ."</option>\n";
          $items_in_group++;
       }
    }
 }
+
 if (!empty($newgroup) && $items_in_group>0) {
    echo $newgroup;
 }
 if (!$first_group) {
    echo "</optgroup>";
 }
-echo "</select>&nbsp;";
-//print_r($_POST);
+echo "</select>";
+
+echo "</td><td class='left'>";
+
 echo "<span id='Search2Span".$_POST["itemtype"].$_POST["num"]."'>\n";
 
-$_POST['itemtype']=$_POST["itemtype"];
-$_POST['num']=$_POST["num"];
-$_POST['field']=$_POST["field"];
-$_POST['searchtype']=$_POST["searchtype2"];
-$_POST['value']=$_POST["value"];
-$_POST['meta']=1;
+$_POST['itemtype']   = $_POST["itemtype"];
+$_POST['num']        = $_POST["num"];
+$_POST['field']      = $_POST["field"];
+$_POST['searchtype'] = $_POST["searchtype2"];
+$_POST['value']      = $_POST["value"];
+$_POST['meta']       = 1;
+
 include (GLPI_ROOT."/ajax/searchoption.php");
 echo "</span>\n";
 
 $params = array('field'       => '__VALUE__',
-                  'itemtype'    => $_POST["itemtype"],
-                  'num'         => $_POST["num"],
-                  'value'       => $_POST["value"],
-                  'searchtype'  => $_POST["searchtype2"],
-                  'meta'        => 1);
-ajaxUpdateItemOnSelectEvent("Search2".$_POST["itemtype"].$_POST["num"],
-                              "Search2Span".$_POST["itemtype"].$_POST["num"],
-                              $CFG_GLPI["root_doc"]."/ajax/searchoption.php",$params,false);
+                 'itemtype'   => $_POST["itemtype"],
+                 'num'        => $_POST["num"],
+                 'value'      => $_POST["value"],
+                 'searchtype' => $_POST["searchtype2"],
+                 'meta'       => 1);
 
+ajaxUpdateItemOnSelectEvent("Search2".$_POST["itemtype"].$_POST["num"],
+                            "Search2Span".$_POST["itemtype"].$_POST["num"],
+                            $CFG_GLPI["root_doc"]."/ajax/searchoption.php", $params, false);
+echo '</td></tr></table>';
 
 ?>
