@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: viewfollowup.php 11453 2010-05-18 06:18:50Z moyo $
+ * @version $Id: viewfollowup.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -33,7 +33,7 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
-$AJAX_INCLUDE=1;
+$AJAX_INCLUDE = 1;
 define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
@@ -47,14 +47,19 @@ if (!isset($_POST['type'])) {
 
 if ($_POST['type']=='TicketTask') {
    $item = new TicketTask();
+
 } else if ($_POST['type']=='TicketFollowup') {
    $item = new TicketFollowup();
+
 } else if ($_POST['type']=='TicketValidation') {
    $item = new TicketValidation();
 }
+
 $ticket = new Ticket();
+
 if (isset($_POST["tickets_id"]) && isset($_POST["id"]) && $ticket->getFromDB($_POST["tickets_id"])) {
    $item->showForm($_POST["id"], array('ticket' => $ticket));
+
 } else {
    echo $LANG['login'][5];
 }
