@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: define.php 14346 2011-05-03 07:28:47Z moyo $
+ * @version $Id: define.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,15 +23,13 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
 */
 
-
-
 // Current version of GLPI
-define("GLPI_VERSION","0.78.5");
+define("GLPI_VERSION","0.80.1");
 define("GLPI_DEMO_MODE","0");
 
 
@@ -43,10 +41,13 @@ $CFG_GLPI['languages'] =  //| NAME in native lang    |LANG FILE  |extjs| tinymce
             'cs_CZ' => array('Čeština',              'cs_CZ.php','cs',    'cs','czech'),
             'de_DE' => array('Deutsch',              'de_DE.php','de',    'de','german'),
             'dk_DK' => array('Dansk',                'dk_DK.php','da',    'da','danish'),
+            'ee_ET' => array('Eesti',                'ee_ET.php','en',    'et','estonian'),
             'en_GB' => array('English',              'en_GB.php','en',    'en','english'),
             'es_AR' => array('Español (Argentina)',  'es_AR.php','es',    'es','spanish'),
             'es_ES' => array('Español (España)',     'es_ES.php','es',    'es','spanish'),
             'es_MX' => array('Español (Mexico)',     'es_MX.php','es',    'es','spanish'),
+            'es_VE' => array('Español (Venezuela)',  'es_VE.php','es',    'es','spanish'),
+            'eu_ES' => array('Euskara',              'eu_ES.php','en',    'en','basque'),
             'fr_FR' => array('Français',             'fr_FR.php','fr',    'fr','french'),
             'gl_ES' => array('Galego',               'gl_ES.php','es',    'gl','galician'),
             'el_EL' => array('Ελληνικά',             'el_EL.php','el_GR', 'el','greek'),
@@ -69,15 +70,19 @@ $CFG_GLPI['languages'] =  //| NAME in native lang    |LANG FILE  |extjs| tinymce
             'sv_SE' => array('Svenska',              'sv_SE.php','sv_SE', 'sv','swedish'),
             'tr_TR' => array('Türkçe',               'tr_TR.php','tr',    'tr','turkish'),
             'ua_UA' => array('Українська',           'ua_UA.php','ukr',   'en','ukrainian'),
-            'ja_JP' => array('日本語',               'ja_JP.php','ja',    'ja','japanese'),
-            'zh_CN' => array('简体中文',             'zh_CN.php','zh_CN', 'zh','simplified chinese'),
-            'zh_TW' => array('繁體中文',             'zh_TW.php','zh_TW', 'zh','traditional chinese'),);
+            'ja_JP' => array('日本語',                'ja_JP.php','ja',    'ja','japanese'),
+            'zh_CN' => array('简体中文',              'zh_CN.php','zh_CN', 'zh','chinese'),
+            'zh_TW' => array('繁體中文',              'zh_TW.php','zh_TW', 'zh','chinese'),);
 
 // Init to store glpi itemtype / tables link
-$CFG_GLPI['glpitables']=array();
+$CFG_GLPI['glpitables'] = array();
 
 define("NOT_AVAILABLE",'N/A');
 
+// key used to crypt passwords in DB for external access : proxy / smtp / ldap /  mailcollectors
+// This key is not used to crypt user's passwords
+// If you hav to define passwords again
+define("GLPIKEY","GLPI£i'snarss'ç");
 
 // TIMES
 define("MINUTE_TIMESTAMP",60);
@@ -146,6 +151,9 @@ define("NORMAL_MODE",0);
 define("TRANSLATION_MODE",1);
 define("DEBUG_MODE",2);
 
+//Management modes
+define("MANAGEMENT_UNITARY",0);
+define("MANAGEMENT_GLOBAL",1);
 
 // DEVICE INTERNAL ACTION
 define("HISTORY_ADD_DEVICE",1);
@@ -167,6 +175,7 @@ define("HISTORY_DEL_RELATION",16);
 define("HISTORY_ADD_SUBITEM",17);
 define("HISTORY_UPDATE_SUBITEM",18);
 define("HISTORY_DELETE_SUBITEM",19);
+define("HISTORY_CREATE_ITEM",20);
 
 // EXPORT TYPE
 define("GLOBAL_SEARCH",-1);
@@ -196,6 +205,11 @@ define("MAIL_SMTP",1);
 define("MAIL_SMTPSSL",2);
 define("MAIL_SMTPTLS",3);
 
+// Auto assign mode for tickets
+define("NO_AUTO_ASSIGN",0);
+define("AUTO_ASSIGN_HARDWARE_CATEGORY",1);
+define("AUTO_ASSIGN_CATEGORY_HARDWARE",2);
+
 
 // MESSAGE TYPE
 define("INFO",0);
@@ -205,82 +219,95 @@ define("ERROR",1);
 define("BOOKMARK_SEARCH",1); //SEARCH SYSTEM bookmark
 
 
+$CFG_GLPI["unicity_types"] = array('Budget', 'Computer', 'Contact', 'Contract', 'Infocom', 'Monitor',
+                                   'NetworkEquipment', 'Peripheral', 'Phone', 'Printer', 'Software',
+                                   'SoftwareLicense', 'Supplier','User');
 
-$CFG_GLPI["state_types"] = array('Computer', 'NetworkEquipment', 'Printer', 'Monitor',
-                                 'Peripheral', 'Phone');
+$CFG_GLPI["state_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral', 'Phone',
+                                 'Printer');
 
-$CFG_GLPI["doc_types"]= array('Budget', 'CartridgeItem', 'ConsumableItem', 'Contact' ,'Contract', 'Computer',
-                              'Entity', 'NetworkEquipment', 'Monitor', 'Peripheral', 'Phone',
-                              'Printer', 'Software', 'SoftwareLicense', 'Supplier', 'Ticket');
+$CFG_GLPI["document_types"]= array('Budget', 'CartridgeItem', 'Computer', 'ConsumableItem',
+                                   'Contact', 'Contract', 'Entity', 'Monitor', 'NetworkEquipment',
+                                   'Peripheral', 'Phone', 'Printer', 'Software', 'SoftwareLicense',
+                                   'Supplier', 'Ticket','User');
 
-$CFG_GLPI["contract_types"] = array('Computer', 'NetworkEquipment', 'Printer', 'Monitor',
-                                    'Peripheral', 'Software', 'Phone');
+$CFG_GLPI["contract_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral',
+                                    'Phone', 'Printer', 'Software');
 
-$CFG_GLPI["infocom_types"] = array('Computer', 'NetworkEquipment', 'Printer', 'Monitor',
-                                   'Peripheral', 'Software', 'CartridgeItem',
-                                   'ConsumableItem', 'Consumable', 'Cartridge', 'Phone',
-                                   'SoftwareLicense');
+$CFG_GLPI["infocom_types"] = array('Cartridge', 'CartridgeItem', 'Computer', 'Consumable',
+                                   'ConsumableItem', 'Monitor', 'NetworkEquipment', 'Peripheral',
+                                   'Phone', 'Printer', 'Software', 'SoftwareLicense');
 
-$CFG_GLPI["reservation_types"] = array('Computer', 'NetworkEquipment', 'Printer', 'Monitor',
-                                       'Peripheral', 'Software','Phone');
+$CFG_GLPI["reservation_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral',
+                                       'Phone', 'Printer', 'Software');
 
-$CFG_GLPI["linkuser_types"] = array('Computer', 'NetworkEquipment', 'Printer', 'Monitor',
-                                    'Peripheral', 'Software', 'Phone');
+$CFG_GLPI["linkuser_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral',
+                                    'Phone', 'Printer', 'Software');
 
-$CFG_GLPI["linkgroup_types"] = array('Computer', 'NetworkEquipment', 'Printer', 'Monitor',
-                                     'Peripheral', 'Software', 'Phone');
+$CFG_GLPI["linkgroup_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral',
+                                     'Phone', 'Printer', 'Software');
 
-$CFG_GLPI["helpdesk_types"] = array('Computer', 'NetworkEquipment', 'Printer', 'Monitor',
-                                    'Peripheral', 'Software', 'Phone');
+$CFG_GLPI["ticket_types"] = array('Computer', 'Monitor', 'NetworkEquipment', 'Peripheral', 'Phone',
+                                  'Printer', 'Software');
 
-$CFG_GLPI["link_types"] = array('Computer', 'NetworkEquipment', 'Printer', 'Monitor',
-                                'Peripheral', 'Software', 'Contact', 'Supplier',
-                                'Contract', 'CartridgeItem', 'ConsumableItem', 'Phone',
-                                'Budget');
+$CFG_GLPI["link_types"] = array('Budget', 'CartridgeItem', 'Computer', 'ConsumableItem', 'Contact',
+                                'Contract', 'Monitor', 'NetworkEquipment', 'Peripheral', 'Phone',
+                                'Printer', 'Software', 'Supplier');
 
-$CFG_GLPI["dictionnary_types"] = array('ComputerModel','ComputerType','MonitorModel','MonitorType',
-                                       'PhoneModel','PhoneType','PrinterModel','PrinterType',
-                                       'PeripheralModel','PeripheralType','NetworkEquipmentModel',
-                                       'NetworkEquipmentType','Software','Manufacturer',
-                                       'OperatingSystem','OperatingSystemServicePack',
-                                       'OperatingSystemVersion');
+$CFG_GLPI["dictionnary_types"] = array('ComputerModel', 'ComputerType', 'Manufacturer',
+                                       'MonitorModel', 'MonitorType', 'NetworkEquipmentModel',
+                                       'NetworkEquipmentType', 'OperatingSystem',
+                                       'OperatingSystemServicePack', 'OperatingSystemVersion',
+                                       'PeripheralModel', 'PeripheralType', 'PhoneModel',
+                                       'PhoneType', 'Printer', 'PrinterModel', 'PrinterType',
+                                       'Software');
 
 $CFG_GLPI["helpdesk_visible_types"] = array('Software');
 
-$CFG_GLPI["netport_types"] = array('Computer', 'NetworkEquipment', 'Printer', 'Peripheral',
-                                   'Phone');
+$CFG_GLPI["networkport_types"] = array('Computer', 'NetworkEquipment', 'Peripheral', 'Phone',
+                                       'Printer');
 
-$CFG_GLPI["massiveaction_noupdate_types"] = array('Entity', 'OcsServer',
-                                                  'Profile','TicketValidation');
+$CFG_GLPI["massiveaction_noupdate_types"] = array('Entity', 'OcsServer', 'Profile',
+                                                  'TicketValidation');
 
-$CFG_GLPI["massiveaction_nodelete_types"] = array('Entity', 'CronTask', 'NotImportedEmail');
+$CFG_GLPI["massiveaction_nodelete_types"] = array('CronTask', 'Entity', 'NotImportedEmail');
 
-$CFG_GLPI["notificationtemplates_types"] = array('Ticket', 'Reservation', 'Cartridge',
-                                                 'Consumable', 'DBConnection', 'Contract',
-                                                  'SoftwareLicense', 'Infocom');
+$CFG_GLPI["notificationtemplates_types"] = array('Cartridge', 'Consumable', 'Contract', 'Crontask',
+                                                 'DBConnection', 'FieldUnicity', 'Infocom',
+                                                 'Reservation', 'SoftwareLicense', 'Ticket', 'User');
 
 $CFG_GLPI["notificationmethods_types"] = array('NotificationMail');
 
-$CFG_GLPI["union_search_type"] = array('ReservationItem'=>"reservation_types",
-                                       'States'=>"state_types");
+$CFG_GLPI["union_search_type"] = array('ReservationItem' => "reservation_types",
+                                       'States'          => "state_types");
 
-$CFG_GLPI["systeminformations_types"] = array ('DBConnection','Plugin','AuthLDAP',
-                                               'MailCollector','OcsServer');
+$CFG_GLPI["systeminformations_types"] = array('AuthLDAP', 'DBConnection', 'MailCollector',
+                                              'OcsServer', 'Plugin');
+
+$CFG_GLPI["rulecollections_types"] = array('RuleImportComputerCollection',
+                                           'RuleMailCollectorCollection', 'RuleOcsCollection',
+                                           'RuleRightCollection', 'RuleSoftwareCategoryCollection',
+                                           'RuleTicketCollection');
+
+// Items which can planned something
+$CFG_GLPI['planning_types'] = array('Reminder','TicketPlanning');
 
 // New config options which can be missing during migration
-$CFG_GLPI["number_format"]=0;
-$CFG_GLPI["decimal_number"]=2;
-$CFG_GLPI["csv_export_delimiter"]=';';
+$CFG_GLPI["number_format"]  = 0;
+$CFG_GLPI["decimal_number"] = 2;
 
 // Default debug options : may be locally overriden
-$CFG_GLPI["debug_sql"]=$CFG_GLPI["debug_vars"]=$CFG_GLPI["debug_lang"]=1;
+$CFG_GLPI["debug_sql"] = $CFG_GLPI["debug_vars"] = $CFG_GLPI["debug_lang"] = 1;
+
 
 
 // User Prefs fields which override $CFG_GLPI config
-$CFG_GLPI['user_pref_field'] = array('date_format','default_requesttypes_id','dropdown_chars_limit',
-      'followup_private','task_private','is_categorized_soft_expanded','is_ids_visible',
-      'is_not_categorized_soft_expanded','language','list_limit','number_format','priority_1',
-      'priority_2','priority_3','priority_4','priority_5','priority_6',
-      'show_jobs_at_login','use_flat_dropdowntree');
+$CFG_GLPI['user_pref_field'] = array('csv_delimiter', 'date_format', 'default_requesttypes_id',
+                                     'dropdown_chars_limit', 'followup_private',
+                                     'is_categorized_soft_expanded', 'is_ids_visible',
+                                     'is_not_categorized_soft_expanded', 'language', 'list_limit',
+                                     'names_format', 'number_format', 'priority_1', 'priority_2',
+                                     'priority_3', 'priority_4', 'priority_5', 'priority_6',
+                                     'show_jobs_at_login', 'task_private','use_flat_dropdowntree');
 
 ?>
