@@ -1,11 +1,9 @@
 <?php
-
-
 /*
- * @version $Id: authmail.form.php 13457 2010-12-24 09:16:05Z remi $
+ * @version $Id: authmail.form.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -25,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -41,7 +39,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 checkRight("config", "w");
 
 if (!isset($_GET["id"])) {
-   $_GET["id"]="";
+   $_GET["id"] = "";
 }
 
 $config_mail = new AuthMail();
@@ -50,26 +48,29 @@ $config_mail = new AuthMail();
 if (isset ($_POST["update"])) {
    $config_mail->update($_POST);
    glpi_header($_SERVER['HTTP_REFERER']);
+
 } else if (isset ($_POST["add"])) {
    //If no name has been given to this configuration, then go back to the page without adding
    if ($_POST["name"] != "") {
-      $newID=$config_mail->add($_POST);
+      $newID = $config_mail->add($_POST);
    }
    glpi_header($_SERVER['HTTP_REFERER']);
+
 } else if (isset ($_POST["delete"])) {
    $config_mail->delete($_POST);
-   $_SESSION['glpi_authconfig']=2;
+   $_SESSION['glpi_authconfig'] = 2;
    $config_mail->redirectToList();
+
 } else if (isset ($_POST["test"])) {
-   if (AuthMail::testAuth($_POST["imap_string"],$_POST["imap_login"],$_POST["imap_password"])) {
+   if (AuthMail::testAuth($_POST["imap_string"], $_POST["imap_login"], $_POST["imap_password"])) {
       addMessageAfterRedirect($LANG['login'][22]);
    } else {
-      addMessageAfterRedirect($LANG['login'][23],false,ERROR);
+      addMessageAfterRedirect($LANG['login'][23], false, ERROR);
    }
    glpi_header($_SERVER['HTTP_REFERER']);
 }
 
-commonHeader($LANG['title'][14], $_SERVER['PHP_SELF'],"config","extauth","imap");
+commonHeader($LANG['title'][14], $_SERVER['PHP_SELF'], "config", "extauth", "imap");
 
 $config_mail->showForm($_GET["id"]);
 
