@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: bookmark.php 12182 2010-08-25 06:20:25Z remi $
+ * @version $Id: bookmark.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -48,7 +48,7 @@ if (!isset($_GET["url"])) {
 $bookmark = new Bookmark;
 
 if (isset($_POST["add"])) {
-   $bookmark->check(-1,'w',$_POST);
+   $bookmark->check(-1, 'w', $_POST);
 
    $bookmark->add($_POST);
    $_GET["action"] = "load";
@@ -61,21 +61,21 @@ if (isset($_POST["add"])) {
    $_GET["action"] = "load";
 
 } else if ($_GET["action"] == "edit" && isset($_GET['mark_default']) && isset($_GET["id"])) {
-   $bookmark->check($_GET["id"],'w');
+   $bookmark->check($_GET["id"], 'w');
 
    if ($_GET["mark_default"] >0) {
       $bookmark->mark_default($_GET["id"]);
    } else if ($_GET["mark_default"]==0) {
       $bookmark->unmark_default($_GET["id"]);
    }
-   $_GET["action"]="load";
+   $_GET["action"] = "load";
 
 } else if ($_GET["action"] == "load" && isset($_GET["id"]) && $_GET["id"]>0) {
-   $bookmark->check($_GET["id"],'r');
+   $bookmark->check($_GET["id"], 'r');
    $bookmark->load($_GET["id"]);
 
 } else if (isset($_POST["delete"])) {
-   $bookmark->check($_POST["id"],'w');
+   $bookmark->check($_POST["id"], 'w');
 
    $bookmark->delete($_POST);
    $_GET["action"] = "load";
@@ -83,7 +83,7 @@ if (isset($_POST["add"])) {
 } else if (isset($_POST["delete_several"])) {
    if (isset($_POST["bookmark"])) {
       foreach ($_POST["bookmark"] as $ID=>$value) {
-         if ($bookmark->can($ID,'w')) {
+         if ($bookmark->can($ID, 'w')) {
             $bookmark->delete(array("id" => $ID));
          }
       }
@@ -95,11 +95,11 @@ if ($_GET["action"] == "edit") {
 
    if (isset($_GET['id']) && $_GET['id']>0) {
       // Modify
-      $bookmark->check($_GET["id"],'w');
+      $bookmark->check($_GET["id"], 'w');
       $bookmark->showForm($_GET['id']);
    } else {
       // Create
-      $bookmark->check(-1,'w');
+      $bookmark->check(-1, 'w');
       $bookmark->showForm(0, array('type'     => $_GET["type"],
                                    'url'      => rawurldecode($_GET["url"]),
                                    'itemtype' => $_GET["itemtype"]));
@@ -116,8 +116,8 @@ if ($_GET["action"] == "edit") {
                        'params' => "target=".$_SERVER['PHP_SELF']."&glpi_tab=0&itemtype=Bookmark");
    }
    echo "<div id='tabspanel' class='center-h'></div>";
-   createAjaxTabs('tabspanel','tabcontent',$tabs,'Bookmark',480);
-   echo "<div id='tabcontent'></div>";
+   createAjaxTabs('tabspanel', 'tabcontent', $tabs, 'Bookmark', Bookmark::WIDTH);
+   echo "<div id='tabcontent'>&nbsp;</div>";
    echo "<script type='text/javascript'>loadDefaultTab();</script>";
 }
 
