@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: budget.form.php 13460 2010-12-24 09:52:58Z remi $
+ * @version $Id: budget.form.php 14684 2011-06-11 06:32:40Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2010 by the INDEPNET Development Team.
+ Copyright (C) 2003-2011 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -23,8 +23,8 @@
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
- along with GLPI; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ along with GLPI; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  --------------------------------------------------------------------------
  */
 
@@ -48,6 +48,8 @@ if (isset($_POST["add"])) {
    $budget->check(-1,'w',$_POST);
 
    if ($newID = $budget->add($_POST)) {
+      $budget->refreshParentInfos();
+
       Event::log($newID, "budget", 4, "financial",
                $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["name"].".");
    }
@@ -73,7 +75,8 @@ if (isset($_POST["add"])) {
    $budget->check($_REQUEST["id"],'w');
 
    if ($budget->delete($_REQUEST,1)) {
-      Event::log($_REQUEST["id"], "budget", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][24]);
+      Event::log($_REQUEST["id"], "budget", 4, "financial",
+                 $_SESSION["glpiname"]." ".$LANG['log'][24]);
    }
    $budget->redirectToList();
 
@@ -86,9 +89,26 @@ if (isset($_POST["add"])) {
    glpi_header($_SERVER['HTTP_REFERER']);
 
 } else {
-   commonHeader($LANG['financial'][87],$_SERVER['PHP_SELF'],"financial","budget");
+   /// TODO To manage using dropdown.common.form
+   if (isset($_GET['popup'])) {
+      popHeader($LANG['financial'][87],$_SERVER['PHP_SELF']);
+      if (isset($_GET["rand"])) {
+         $_SESSION["glpipopup"]["rand"] = $_GET["rand"];
+      }
+
+   } else {
+      commonHeader($LANG['financial'][87],$_SERVER['PHP_SELF'],"financial","budget");
+   }
    $budget->showForm($_GET["id"], array('withtemplate' => $_GET["withtemplate"]));
-   commonFooter();
+
+   if (isset($_GET['popup'])) {
+      echo "<div class='center'><br><a href='javascript:window.close()'>".$LANG['buttons'][13]."</a>";
+      echo "</div>";
+
+      popFooter();
+   } else {
+      commonFooter();
+   }
 }
 
 ?>
